@@ -304,7 +304,7 @@ start_anim_cb(Widget widget, XtPointer client_data, XtPointer call_data)
   
   stop_anim=0;
 
-  if(no_frames==0){
+  if(no_frames < 2){
     return;
   }
 
@@ -358,7 +358,7 @@ start_anim_cb(Widget widget, XtPointer client_data, XtPointer call_data)
     usleep(10000*(frame_speed - 1));
 #endif
 
-    if((stop_anim==1) || (no_frames==1)){
+    if(stop_anim == 1){
       return;
     } /* stop button pressed; leave loop */
   }
@@ -461,7 +461,7 @@ bounce_cb(Widget widget, XtPointer client_data, XtPointer call_data)
   
   stop_anim=0;
 
-  if(no_frames==0){
+  if(no_frames < 2){
     return;
   }
 
@@ -469,8 +469,14 @@ bounce_cb(Widget widget, XtPointer client_data, XtPointer call_data)
     
     if(frame_no==no_frames-1){
       frame_step=-1;
+#ifdef HAVE_USLEEP
+      usleep(200000*(frame_speed));
+#endif
     }else if(frame_no==0){
       frame_step=1;
+#ifdef HAVE_USLEEP
+      usleep(200000*(frame_speed));
+#endif
     }
 
     frame_no+=frame_step;
@@ -517,7 +523,7 @@ bounce_cb(Widget widget, XtPointer client_data, XtPointer call_data)
     usleep(10000*(frame_speed-1));
 #endif
     
-    if((stop_anim==1) || (no_frames==1)){
+    if(stop_anim == 1){
       return;
     } /* stop button pressed; leave loop */
   }
@@ -685,7 +691,6 @@ change_frame(int frame_no, Boolean update_label, Boolean centre_this_frame)
 {
 
   double get_angle_axis(double *);
-  int get_element_index_for_type (char *);
   void canvas_cb(Widget, XtPointer, XtPointer);
   void centre_atoms(void);
   void make_label_uppercase (char *);
@@ -701,9 +706,7 @@ change_frame(int frame_no, Boolean update_label, Boolean centre_this_frame)
 
   /* if no frames, return ... */
 
-  if(no_frames==0){
-    return;
-  }
+  if(no_frames == 0) return;
 
   frame_content_to_atoms (frame_no);
 
