@@ -24,6 +24,15 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #define MAX_VECTORS_PER_ATOM (3)
 
+/* enum types */
+
+enum gl_render_types
+{
+  DEFAULT,
+  BALL_AND_STICK,
+  TUBES
+};
+
 struct atoms {
   char label[4];
   char uppercase_label[4];
@@ -49,6 +58,7 @@ struct atoms {
   int type;          /* atom type index */
   int has_vector;
   int is_ellipse;
+  enum gl_render_types gl_render_type;
 };
 
 struct elements {
@@ -86,6 +96,12 @@ struct atom
   int has_vector;
   int is_ellipse;
   Boolean visi;
+  /* Override default colors: either RGB or name */
+  Boolean has_rgb;
+  double red, green, blue;
+  Boolean has_color_name;
+  char color_name[32];
+  enum gl_render_types gl_render_type;
 };
   
 struct frame
@@ -116,7 +132,7 @@ int no_atom_types;
 int rotate_about = ROTATE_ABOUT_LOCAL_COM;
 int *atom_types;
 
-int no_frames;
+int no_frames = 0;
 int frame_no;
 int sel_init=0;
 int selected[4];
@@ -130,6 +146,8 @@ Dimension canvas_height=450;
 
 char bg_color[30]="lightgray";
 char bb_color[30]="darkgray";
+char sel_color_name[30]="orange";
+XColor sel_color;
 char current_file_name[1024] = ""; /* aro */
 
 double depth;
@@ -145,6 +163,7 @@ Boolean redraw;
 Boolean inhibit_canvas_callback = 0;
 Boolean centre_each_frame=0;
 Boolean depth_is_on=1;
+Boolean never_use_vdw = 0;
 Boolean atoms_sorted=0;
 Boolean any_hydrogen;
 Boolean view_ghost_atoms = False;
@@ -205,6 +224,8 @@ extern Dimension canvas_height;
 
 extern char bg_color[30];
 extern char bb_color[30];
+extern char sel_color_name[30];
+extern XColor sel_color;
 extern char current_file_name[1024]; /* aro */
 
 extern double depth;
@@ -220,6 +241,7 @@ extern Boolean redraw;
 extern Boolean inhibit_canvas_callback;
 extern Boolean centre_each_frame;
 extern Boolean depth_is_on;
+extern Boolean never_use_vdw;
 extern Boolean atoms_sorted;
 extern Boolean any_hydrogen;
 extern Boolean view_ghost_atoms;
